@@ -5,10 +5,10 @@
  * @package   PukiWiki
  * @access    public
  * @author    Logue <logue@hotmail.co.jp>
- * @copyright 2012-2014 PukiWiki Advance Developers Team
+ * @copyright 2012-2015 PukiWiki Advance Developers Team
  * @create    2012/12/18
  * @license   GPL v2 or (at your option) any later version
- * @version   $Id: Render.php,v 1.0.0 2014/03/12 20:12:00 Logue Exp $
+ * @version   $Id: Render.php,v 1.0.1 2015/02/27 21:32:00 Logue Exp $
  */
 
 namespace PukiWiki;
@@ -24,6 +24,8 @@ use PukiWiki\Time;
 use Zend\Http\Response;
 use Zend\Json\Json;
 use PukiWiki\File\File;
+use PukiWiki\File\AttachFile;
+use PukiWiki\File\AttachLogFile;
 
 /**
  * ページ出力クラス
@@ -40,24 +42,24 @@ class Render{
 	/**
 	 * jQueryのバージョン
 	 */
-	const JQUERY_VER = '2.1.1';
-	//const JQUERY_VER = '1.11.1';
+	const JQUERY_VER = '2.1.3';
+	//const JQUERY_VER = '1.11.2';
 	/**
 	 * jQuery UIのバージョン
 	 */
-	const JQUERY_UI_VER = '1.11.1';
+	const JQUERY_UI_VER = '1.11.4';
 	/**
 	 * jQuery Mobileのバージョン
 	 */
-	const JQUERY_MOBILE_VER = '1.4.3';
+	const JQUERY_MOBILE_VER = '1.4.5';
 	/**
 	 * Twitter Bootstrapのバージョン
 	 */
-	const TWITTER_BOOTSTRAP_VER = '3.2.0';
+	const TWITTER_BOOTSTRAP_VER = '3.3.4';
 	/**
 	 * Font Awesomeのバージョン
 	 */
-	const FONT_AWESOME_VER = '4.2.0';
+	const FONT_AWESOME_VER = '4.3.0';
 	/**
 	 * スキンスクリプト（未圧縮）
 	 */
@@ -96,14 +98,12 @@ class Render{
 		'jquery.autosize',
 		'jquery.cookie',
 		'jquery.dataTables',
-		'jquery.dataTables.naturalsort',
 		'jquery.form',
 		'jquery.i18n',
 		'jquery.query',
 		'jquery.superfish',
 		'jquery.tabby',
-		'jquery.ui.rlightbox',
-		'dataTables.jqueryui'
+		'jquery.ui.rlightbox'
 	);
 	/**
 	 * モバイル時読み込むスクリプト
@@ -124,6 +124,7 @@ class Render{
 		global $vars, $lastmod;
 		$this->page = isset($vars['page']) ? $vars['page'] : null;
 		$this->ajax = isset($vars['ajax']) ? $vars['ajax'] : null;
+		$this->cmd = isset($vars['cmd']) ? $vars['cmd'] : 'read';	// ※通常は空にならない
 		$this->wiki = !empty($this->page) ? Factory::Wiki($this->page) : null;
 		$this->title = $title;
 		$this->body = $body;
@@ -138,7 +139,10 @@ class Render{
 			break;
 			case 'xml':
 				$content_type = 'application/xml';
-				$content = '<?xml version="1.0" encoding="'.CONTENT_CHARSET.'" ?>'."\n".$this->body;
+				$content = '<' . '?xml version="1.0" encoding="UTF-8" ?' . '>'."\n".'<response>' . "\n" . 
+				'<title>' . $this->title . '</title>' . "\n" . 
+				'<body><![CDATA[' . $this->body . ']]></body>' . "\n" .
+				'<process_time>' . Time::getTakeTime() . '</process_time>' . "\n" . '</response>';
 			break;
 			case 'raw':
 				$content_type = 'text/plain';
@@ -165,28 +169,36 @@ class Render{
 	 * @return string
 	 */
 	public function getContent(){
-		global $_LINK, $info, $vars, $_LANG;
-		global $site_name, $newtitle, $modifier, $modifierlink, $menubar, $sidebar, $headarea, $footarea, $navigation, $attach_link, $related_link;
+		global $_LINK, $info, $_LANG;
+		global $site_name, $newtitle, $modifier, $modifierlink, $menubar, $sidebar, $headarea, $footarea, $navigation;
 
 		$body = $this->body;
 
+		// Linkタグ
 		$_LINK = self::getLinkSet($this->page);
 
 		// ページをコンストラクト
 		$view = new View(PLUS_THEME);
 
-		$view->is_page = isset($vars['page']);
-		$view->is_read = isset($vars['cmd']) && $vars['cmd'] === 'read';
-		$view->is_freeze = isset($vars['page']) ? Factory::Wiki($vars['page'])->isFreezed() : false;
+		// ページ名が指定されているか
+		$view->is_page = isset($this->page);
+		// readプラグイン（通常時動作）か？
+		$view->is_read = $this->cmd === 'read';
+		// ページが凍結されているか
+		$view->is_freeze = isset($this->page) ? Factory::Wiki($this->page)->isFreezed() : false;
 
-		if ($vars['cmd'] === 'read'){
+		if ($this->cmd === 'read'){
+			// ページを読み込む場合
 			global $adminpass, $_string, $menubar, $sidebar;
+			
+			// パスワードがデフォルトのままだった時に警告を出す
 			if ($adminpass == '{x-php-md5}1a1dc91c907325c69271ddf0c944bc72' || $adminpass == '' ){
 				$body = '<p class="alert alert-danger"><span class="fa fa-exclamation-triangle"></span>'.
 					'<strong>'.$_string['warning'].'</strong> '.$_string['changeadminpass'].'</p>'."\n".
 					$body;
 			}
 
+			// デバッグモード時に記載
 			if (DEBUG === true && ! empty($info)){
 				$body = '<div class="panel panel-info" id="pkwk-info">'.
 						'<div class="panel-heading"><span class="fa fa-info-circle"></span>'.$_string['debugmode'].'</div>'."\n".
@@ -195,19 +207,16 @@ class Render{
 						'</ul></div></div>'."\n\n".$body;
 			}
 			// リファラーを保存
-			if ($this->page !== null) Factory::Referer($this->page)->set();
+			Factory::Referer($this->page)->set();
 
+			// 最終更新日
 			$view->lastmodified = '<time datetime="'.Time::getZoneTimeDate('c',$this->wiki->time()).'">'.Time::getZoneTimeDate('D, d M Y H:i:s T', $this->wiki->time()) . ' ' . $this->wiki->passage().'</time>';
+			// ページの添付ファイル
+			$view->attaches = $this->getAttaches();
+			// 関連リンク
+			$view->related = $this->getRelated();
 
-			// ページの添付ファイル、関連リンク
-			if ($attach_link) {
-				$view->attaches = $this->getAttaches();
-			}
-			if ($related_link) {
-				$view->related = $this->getRelated();
-			}
-
-			// ノート
+			// 注釈
 			global $foot_explain;
 			ksort($foot_explain, SORT_NUMERIC);
 			$notes = ! empty($foot_explain) ? '<ul>'.join("\n", $foot_explain).'</ul>' : '';
@@ -215,36 +224,36 @@ class Render{
 			// 検索語句をハイライト
 			if (isset($vars['word'])){
 				$notes = self::hilightWord($vars['word'],$notes);
-				$body = '<p class="alert alert-info">' . $_string['word'] . '<var>' . Utility::htmlsc($vars['word']) . '</var></p>'."\n".'<hr />'."\n".self::hilightWord($vars['word'], $body);
+				$body = '<p class="alert alert-info">' . $_string['word'] . '<var>' . Utility::htmlsc($vars['word']) . '</var></p>' . "\n" .
+					'<hr />' . "\n" . self::hilightWord($vars['word'], $body);
 			}
 			$view->notes = $notes;
-		}
 
-		// モードによって、3カラム、2カラムを切り替える。
-		if ($vars['cmd'] === 'read') {
+			// モードによって、3カラム、2カラムを切り替える。
 			$view->menubar = Factory::Wiki($menubar)->has() ? PluginRenderer::executePluginBlock('menu') : null;
 			if ( Factory::Wiki($sidebar)->has()){
+				// サイドバーが定義されている場合３カラム
 				$view->sidebar = Factory::Wiki($sidebar)->has() ? PluginRenderer::executePluginBlock('side') : null;
 				$view->colums = View::CLASS_THREE_COLUMS;
 			}else{
 				$view->colums = View::CLASS_TWO_COLUMS;
 			}
-		}else{
-			$view->colums = View::CLASS_NO_COLUMS;
-		}
-		
-		// ステータスアイコン
-		$view->status = '';
-		if ($this->wiki || $vars['cmd'] === 'read') {
-			
+
+			// ステータスアイコン
 			if ($this->wiki->isFreezed()){
+				// 錠前マーク（フリーズされてる）
 				$view->status = '<span class="fa fa-lock" title="Freezed"></span>';
 			}else if (!$this->wiki->isEditable()){
+				// 駐禁マーク（編集できない）
 				$view->status = '<span class="fa fa-ban" title="Not Editable"></span>';
 			}else{
+				// 鉛筆マーク（編集できる）
 				$view->status = '<span class="fa fa-pencil-square" title="Editable"></span>';
 			}
 		}else{
+			// プラグインを実行する場合、大抵の場合メニューバーやサイドバーを表示しない
+			$view->colums = View::CLASS_NO_COLUMS;
+			// ステータスアイコンを歯車にする
 			$view->status = '<span class="fa fa-cog" title="Function mode"></span>';
 		}
 
@@ -288,6 +297,8 @@ class Render{
 		$view->proc_time = $this->getProcessTime();
 		// メモリ使用量
 		$view->memory = $this->getMemoryUsage();
+		
+		// このへんにViewオブジェクトのキャッシュ処理を入れれば大幅に速くなるが・・・。
 
 		return $view->__toString();
 	}
@@ -332,7 +343,7 @@ class Render{
 
 		// JavaScriptタグの組み立て
 		if (isset($vars['page'])){
-			$js_init['PAGE'] = rawurlencode($vars['page']);
+			$js_init['PAGE'] = str_replace('%2F', '/' ,rawurlencode($vars['page']));
 			$js_init['MODIFIED'] = $this->wiki->time();
 		}
 
@@ -357,7 +368,7 @@ class Render{
 			$pkwk_head_js[] = array('type'=>'text/javascript', 'src'=>JS_URI.(IS_MOBILE ? self::MOBILE_JS_COMPRESSED : self::DEFAULT_JS_COMPRESSED), 'defer'=>'defer' );
 		}
 
-		$pkwk_head_js[] = array('type'=>'text/javascript', 'src'=>JS_URI.( DEBUG ? 'locale.js' : 'js.php?file=locale'), 'defer'=>'defer' );
+		$pkwk_head_js[] = array('type'=>'text/javascript', 'src'=>JS_URI.'locale.js', 'defer'=>'defer' );
 
 //		$pkwk_head_js[] = array('type'=>'text/javascript', 'src'=>JS_URI.( DEBUG ? 'codemirror/lib/codemirror.js' : 'js.php?file=codemirror/lib/codemirror.min'), 'defer'=>'defer' );
 
@@ -389,7 +400,7 @@ class Render{
 	 * @return string
 	 */
 	private function getHead($conf){
-		global $vars, $nofollow, $google_analytics, $google_api_key, $google_site_verification, $yahoo_site_explorer_id, $bing_webmaster_tool, $shortcut_icon, $modifier, $modifierlink;
+		global $vars, $google_analytics, $google_api_key, $google_site_verification, $yahoo_site_explorer_id, $bing_webmaster_tool, $shortcut_icon, $modifier, $modifierlink;
 		$meta_tags[] = array('charset'=>constant('SOURCE_ENCODING'));
 		// $meta_tags[] = array('http-equiv'=>'x-dns-prefetch-control','content'=>'on');
 		if (IS_MOBILE){
@@ -405,11 +416,7 @@ class Render{
 			// Bing（MSN）アクセス解析
 			(!empty($bing_webmaster_tool)) ?		$meta_tags[] = array('name' => 'msvalidate.01',				'content' => $bing_webmaster_tool) : null;
 
-			if ($nofollow && $vars['cmd'] === 'read'){
-				$meta_tags[] = array('name' => 'robots', 'content' => 'NOINDEX,NOFOLLOW');
-			}
-
-			if (!empty($this->wiki) && $vars['cmd'] === 'read'){
+			if ($this->cmd === 'read'){
 				global $keywords, $description, $site_name, $site_logo;
 				// 要約
 				$desc = !empty($description) ? $description : $this->wiki->description();
@@ -432,7 +439,11 @@ class Render{
 				if (isset($fb)){
 					$meta_tags[] = array('property' => 'fb:app_id', 'content' => $fb->getAppId());
 				}
+			} else if ($this->cmd !== 'list'){
+				// Listプラグイン以外はロボットにキャッシュさせない
+				$meta_tags[] = array('name' => 'robots', 'content' => 'noindex,nofollow,noarchive,noodp,noydir');
 			}
+
 			// Linkタグの生成
 			// scriptタグと異なり、順番が変わっても処理への影響がない。
 			// http://www.w3schools.com/html5/tag_link.asp
@@ -451,7 +462,11 @@ class Render{
 				array('rel'=>'search',			'href'=>$_LINK['search'],	'type'=>'text/html',	'title'=>$_LANG['skin']['search']),
 				array('rel'=>'shortcut icon',	'href'=>isset($conf['shortcut_icon']) ? $conf['shortcut_icon'] : WWW_HOME . 'favicon.ico'),
 				array('rel'=>'sidebar',			'href'=>$_LINK['side'],		'type'=>'text/html',	'title'=>$_LANG['skin']['side']),
-				array('rel'=>'sitemap',			'href'=>$_LINK['sitemap'],	'type'=>'application/xml')
+				array('rel'=>'sitemap',			'href'=>$_LINK['sitemap'],	'type'=>'application/xml'),
+				
+				// Pubsubhubbub
+				array('rel'=>'hub',			'href'=>'http://pubsubhubbub.appspot.com/'),
+				array('rel'=>'self',			'href'=>$_LINK['atom'],		'type'=>'application/atom+xml')
 			);
 		}
 
@@ -541,6 +556,7 @@ class Render{
 
 				'sitemap'       => Router::get_resolve_uri('list',    null, 'full',   array('type'=>'sitemap')),
 				'rss'           => Router::get_resolve_uri('feed', null, 'full'),
+				'atom'          => Router::get_resolve_uri('feed', null, 'full', array('type'=>'atom')),
 
 				'read'          => Router::get_resolve_uri('read', $_page),
 				'reload'        => Router::get_resolve_uri('read', $_page, 'full'),
@@ -736,17 +752,19 @@ class Render{
 			$ret[] = '<dt>'.$_LANG['skin']['attach_title'].'</dt>';
 			foreach ($attaches as $filename=>$files){
 				if (!isset($files[0])) continue;
-				$fileinfo = new File(UPLOAD_DIR . $files[0]);
+				$fileinfo = new AttachFile($this->page, $filename);
 				$exists = true;
 				if (!$fileinfo->has()) continue;
-				$logfileinfo = new File(UPLOAD_DIR . $files['log']);
-				$count = $logfileinfo->has() ? $logfileinfo->head(0) : '0';
+			//	$logfileinfo = new AttachFile($this->page, $filename, 'log');
+			//	var_dump($logfileinfo->filename);
+			//	$count = $logfileinfo->has() ? $logfileinfo->head(0) : '0';
+				
 				$ret[] = '<dd><a href="' . 
 					Router::get_cmd_uri('attach', null, null, array('pcmd'=>'open','refer'=>$this->page, 'age'=>0, 'openfile'=>$filename)) .
 					'" title="' . Time::getZoneTimeDate('Y/m/d H:i:s', $fileinfo->time()) . ' ' .
 					sprintf('%01.1f', round($fileinfo->getSize()/1024, 1)) . 'KB' .
 					'"><span class="fa fa-download"></span>'.Utility::htmlsc($filename).'</a> ' .
-					'<small>(<var>' . $count . '</var>)</small> ' .
+			//		'<small>(<var>' . $count . '</var>)</small> ' .
 					'<a href="' . Router::get_cmd_uri('attach', null, null, array('pcmd'=>'info','refer'=>$this->page, 'file'=>$filename)) . '" class="btn btn-default btn-xs" title="'.$_LANG['skin']['attach_info'].'">' .
 					'<span class="fa fa-info"></span></a>' .
 					'</dd>';
